--[[
Author: Ayantir
Filename: SunTzu.lua
Version: 0.1
]]--

--Libraries
local LMP = LibStub("LibMapPins-1.0")
--Constants
local BOSSES = "SunTzu_Bosses"
local BOSSES_OTHER = "SunTzu_Other"

local bosses = false
local others = false

--Default Variables
local savedVariables
local defaults = {
	showBosses = {
		[BOSSES] = true,
		[BOSSES_OTHER] = true,
	}
}

--Tooltip Creator
local pinTooltipCreator = {}
pinTooltipCreator.tooltip = 1
pinTooltipCreator.creator = function(pin)

	local _, pinTag = pin:GetPinTypeAndTag()
	local name = pinTag[3]
	local description = pinTag[4]

	InformationTooltip:AddLine(name, "ZoFontGameOutline", ZO_SELECTED_TEXT:UnpackRGB())
	ZO_Tooltip_AddDivider(InformationTooltip)
	local r, g, b = ZO_HIGHLIGHT_TEXT:UnpackRGB()
	InformationTooltip:AddLine(description, "ZoFontGame", r, g, b, TOPLEFT, MODIFY_TEXT_TYPE_NONE, TEXT_ALIGN_CENTER, true)
	
end

-- Where shall be displayed our pins
local function MapCallback_bosses()
	
	local typeof = BOSSES
	if LMP:IsEnabled(typeof) then
		local zone, subzone = LMP:GetZoneAndSubzone()
		if (IsUnitUsingVeteranDifficulty("player")) then
			local pins = SunTzu_GetLocalData(zone, subzone, typeof)
			if pins ~= nil then
				for _, pinData in ipairs(pins) do
					LMP:CreatePin(typeof, pinData, pinData[1], pinData[2])
				end
			end
		end
	end
		
end

-- Where shall be displayed our pins
local function MapCallback_others()
	
	local typeof = BOSSES_OTHER
	if LMP:IsEnabled(typeof) then
		local zone, subzone = LMP:GetZoneAndSubzone()
		if (IsUnitUsingVeteranDifficulty("player")) then
			local pins = SunTzu_GetLocalData(zone, subzone, typeof)
			if pins ~= nil then
				for _, pinData in ipairs(pins) do
					LMP:CreatePin(typeof, pinData, pinData[1], pinData[2])
				end
			end
		end
	end
	
end

-- Load Addon
local function OnLoad(_, name)
	if name ~= "SunTzu" then return end
	EVENT_MANAGER:UnregisterForEvent("SunTzu", EVENT_ADD_ON_LOADED)

	savedVariables = ZO_SavedVars:New("SunTzu_SavedVars" , 1, nil, defaults)
	
	local pins = {
		[BOSSES] = {level = 120, texture = "/esoui/art/icons/poi/poi_groupboss_complete.dds", size = 38},
		[BOSSES_OTHER] = {level = 120, texture = "/esoui/art/icons/poi/poi_areaofinterest_complete.dds", size = 38}
	}
	
	--Initialize map pins, will be run at each map change.
	LMP:AddPinType(BOSSES, MapCallback_bosses, nil, pins[BOSSES], pinTooltipCreator)
	LMP:AddPinType(BOSSES_OTHER, MapCallback_others, nil, pins[BOSSES_OTHER], pinTooltipCreator)
	
	--Add filter checkbox
	LMP:AddPinFilter(BOSSES, GetString(SUNTZU_FILTER_BOSSES), nil, savedVariables.showBosses)
	LMP:AddPinFilter(BOSSES_OTHER, GetString(SUNTZU_FILTER_BOSSES_OTHER), nil, savedVariables.showBosses)

end

EVENT_MANAGER:RegisterForEvent("SunTzu", EVENT_ADD_ON_LOADED, OnLoad)